@@ -1,4 +1,4 @@
-__version__ = '1.3'
+__version__ = '1.4'
 
 from redis import Redis
 import pyres.json_parser as json
@@ -20,7 +20,7 @@ def get_logging_handler(filename, procname, namespace=None):
         message_format = namespace + ': %(message)s'
     else:
         message_format = '%(message)s'
-    format = '%(asctime)s %(levelname)-8s ' + message_format
+    format = '%(asctime)s %(process)5d %(levelname)-8s ' + message_format
 
     if not filename:
         filename = "stderr"
@@ -140,9 +140,8 @@ class ResQ(object):
 
     """
     def __init__(self, server="localhost:6379", password=None):
+        self.password = password
         self.redis = server
-        if password:
-            self.redis.auth(password)
         self._watched_queues = set()
 
     def push(self, queue, item):
@@ -187,7 +186,7 @@ class ResQ(object):
         if isinstance(server, basestring):
             self.dsn = server
             host, port = server.split(':')
-            self._redis = Redis(host=host, port=int(port))
+            self._redis = Redis(host=host, port=int(port), password=self.password)
             self.host = host
             self.port = int(port)
         elif isinstance(server, Redis):
@@ -212,17 +211,12 @@ class ResQ(object):
         queue = getattr(klass,'queue', None)
         if queue:
             class_name = '%s.%s' % (klass.__module__, klass.__name__)
-            self.push(queue, {'class':class_name,'args':args})
-            logging.info("enqueued '%s' job on queue %s" % (class_name, queue))
-            if args:
-                logging.debug("job arguments: %s" % str(args))
-            else:
-                logging.debug("no arguments passed in.")
+            self.enqueue_from_string(class_name, queue, *args)
         else:
             logging.warning("unable to enqueue job with class %s" % str(klass))
 
     def enqueue_from_string(self, klass_as_string, queue, *args, **kwargs):
-        payload = {'class':klass_as_string, 'queue': queue, 'args':args}
+        payload = {'class':klass_as_string, 'args':args, 'enqueue_timestamp': time.time()}
         if 'first_attempt' in kwargs:
             payload['first_attempt'] = kwargs['first_attempt']
         self.push(queue, payload)
@@ -286,11 +280,14 @@ class ResQ(object):
 
     def enqueue_at(self, datetime, klass, *args, **kwargs):
         class_name = '%s.%s' % (klass.__module__, klass.__name__)
+        self.enqueue_at_from_string(datetime, class_name, klass.queue, *args, **kwargs)
+
+    def enqueue_at_from_string(self, datetime, klass_as_string, queue, *args, **kwargs):
         logging.info("scheduled '%s' job on queue %s for execution at %s" %
-                     (class_name, klass.queue, datetime))
+                     (klass_as_string, queue, datetime))
         if args:
             logging.debug("job arguments are: %s" % str(args))
-        payload = {'class':class_name, 'queue': klass.queue, 'args':args}
+        payload = {'class': klass_as_string, 'queue': queue, 'args': args}
         if 'first_attempt' in kwargs:
             payload['first_attempt'] = kwargs['first_attempt']
         self.delayed_push(datetime, payload)
@@ -356,7 +353,8 @@ class ResQ(object):
         _self = cls()
         if queue:
             class_name = '%s.%s' % (klass.__module__, klass.__name__)
-            _self.push(queue, {'class':class_name,'args':args})
+            _self.push(queue, {'class':class_name,'args':args,
+                               'enqueue_timestamp': time.time()})
 
     @staticmethod
     def _current_time():
